==> mailutils-0.6.tar.bz2: mailutils-0.6/mailbox/nntp/nntp_carrier.c <==
/* GNU Mailutils -- a suite of utilities for electronic mail
   Copyright (C) 2004 Free Software Foundation, Inc.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <mailutils/sys/nntp.h>

int
mu_nntp_set_carrier (mu_nntp_t nntp, stream_t carrier)
{
  /* Sanity checks.  */
  if (nntp == NULL)
    return EINVAL;

  if (nntp->carrier)
    {
      /* Close any old carrier.  */
      mu_nntp_disconnect (nntp);
      stream_destroy (&nntp->carrier, nntp);
    }
  nntp->carrier = carrier;
  return 0;
}

int
mu_nntp_get_carrier (mu_nntp_t nntp, stream_t *pcarrier)
{
  /* Sanity checks.  */
  if (nntp == NULL)
    return EINVAL;
  if (pcarrier == NULL)
    return MU_ERR_OUT_PTR_NULL;

  *pcarrier = nntp->carrier;
  return 0;
}

==> mailutils-0.6.90.tar.bz2: mailutils-0.6.90/mailbox/nntp/nntp_carrier.c <==
/* GNU Mailutils -- a suite of utilities for electronic mail
   Copyright (C) 2004 Free Software Foundation, Inc.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General
   Public License along with this library; if not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301 USA */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <mailutils/sys/nntp.h>

int
mu_nntp_set_carrier (mu_nntp_t nntp, stream_t carrier)
{
  /* Sanity checks.  */
  if (nntp == NULL)
    return EINVAL;

  if (nntp->carrier)
    {
      /* Close any old carrier.  */
      mu_nntp_disconnect (nntp);
      stream_destroy (&nntp->carrier, nntp);
    }
  nntp->carrier = carrier;
  return 0;
}

int
mu_nntp_get_carrier (mu_nntp_t nntp, stream_t *pcarrier)
{
  /* Sanity checks.  */
  if (nntp == NULL)
    return EINVAL;
  if (pcarrier == NULL)
    return MU_ERR_OUT_PTR_NULL;

  *pcarrier = nntp->carrier;
  return 0;
}
